@@ -1,6 +1,6 @@
-__version__ = '0.0.26'
+__version__ = '0.0.34'
 
-import elbus
+import busrt
 import sys
 import msgpack
 import logging
@@ -223,54 +223,54 @@ class Controller:
     def event_pending(self, action):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(
+            busrt.client.Frame(payload=_action_event_payload(
                 action.uuid, ACTION_PENDING),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def event_running(self, action):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(
+            busrt.client.Frame(payload=_action_event_payload(
                 action.uuid, ACTION_RUNNING),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def event_completed(self, action, out=None):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(action.uuid,
+            busrt.client.Frame(payload=_action_event_payload(action.uuid,
                                                              ACTION_COMPLETED,
                                                              out=out,
                                                              exitcode=0),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def event_failed(self, action, out=None, err=None, exitcode=None):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(action.uuid,
+            busrt.client.Frame(payload=_action_event_payload(action.uuid,
                                                              ACTION_FAILED,
                                                              out=out,
                                                              err=err,
                                                              exitcode=exitcode),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def event_canceled(self, action):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(
+            busrt.client.Frame(payload=_action_event_payload(
                 action.uuid, ACTION_CANCELED),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def event_terminated(self, action):
         self.bus.send(
             f'ACT/{action.i.to_path()}',
-            elbus.client.Frame(payload=_action_event_payload(
+            busrt.client.Frame(payload=_action_event_payload(
                 action.uuid, ACTION_TERMINATED),
-                               tp=elbus.client.OP_PUBLISH,
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
 
@@ -297,7 +297,7 @@ class EvaLogHandler(logging.Handler):
             msg = f'CRITICAL: {msg}'
         self.bus.send(
             topic,
-            elbus.client.Frame(msg.encode(), tp=elbus.client.OP_PUBLISH, qos=0))
+            busrt.client.Frame(msg.encode(), tp=busrt.client.OP_PUBLISH, qos=0))
 
 
 class Service:
@@ -317,7 +317,7 @@ class Service:
         self.log_format = ('mod:%(module)s fn:%(funcName)s '
                            'th:%(threadName)s :: %(message)s')
         self.log_formatter = logging.Formatter(self.log_format)
-        self.on_rpc_call = elbus.rpc.on_call_default
+        self.on_rpc_call = busrt.rpc.on_call_default
         self.shutdown_requested = False
         self.eva_dir = self.initial['core']['path']
         user = self.initial.get('user')
@@ -346,9 +346,10 @@ class Service:
         threading.Thread(target=self._t_stdin_watcher, daemon=True).start()
 
     def _t_stdin_watcher(self):
+        f = open(sys.stdin.fileno(), 'rb')
         while self.active:
             try:
-                buf = sys.stdin.buffer.read(1)
+                buf = f.read(1)
             except:
                 self.mark_terminating()
                 break
@@ -357,7 +358,7 @@ class Service:
                 break
             time.sleep(0.1)
 
-    def is_mode_rft(self):
+    def is_mode_rtf(self):
         return self.initial.get('fail_mode', False)
 
     def is_mode_normal(self):
@@ -365,7 +366,7 @@ class Service:
 
     def need_ready(self):
         if not self.active:
-            raise elbus.rpc.RpcException('service not ready',
+            raise busrt.rpc.RpcException('service not ready',
                                          ERR_CODE_INTERNAL_RPC)
 
     def get_config(self):
@@ -379,7 +380,7 @@ class Service:
         bus_config = self.initial['bus']
         if bus_config['type'] != 'native':
             raise ValueError(f'bus {bus_config["type"]} is not supported')
-        self.bus = elbus.client.Client(bus_config['path'], self.id)
+        self.bus = busrt.client.Client(bus_config['path'], self.id)
         self.bus.buf_size = bus_config['buf_size']
         self.bus.timeout = bus_config['timeout']
         self.bus.ping_interval = bus_config['ping_interval']
@@ -387,7 +388,7 @@ class Service:
 
     def init_rpc(self, svc_info):
         self._svc_info = pack(svc_info.serialize())
-        self.rpc = elbus.rpc.Rpc(self.bus)
+        self.rpc = busrt.rpc.Rpc(self.bus)
         self.rpc.on_call = self._handle_rpc_call
 
     def wait_core(self, timeout=None, wait_forever=True):
@@ -398,7 +399,7 @@ class Service:
             try:
                 result = self.rpc.call(
                     'eva.core',
-                    elbus.rpc.Request('test')).wait_completed(timeout)
+                    busrt.rpc.Request('test')).wait_completed(timeout)
                 if unpack(result.get_payload())['active'] is True:
                     return
             except:
@@ -423,6 +424,7 @@ class Service:
         level = self.initial['core']['log_level']
         logging.basicConfig(level=level)
         logger = logging.getLogger()
+        logger.setLevel(level)
         while logger.hasHandlers():
             logger.removeHandler(logger.handlers[0])
         self.log_handler = EvaLogHandler(self.bus)
@@ -461,8 +463,8 @@ class Service:
     def _mark(self, status):
         self.bus.send(
             'SVC/ST',
-            elbus.client.Frame(pack({'status': status}),
-                               tp=elbus.client.OP_PUBLISH,
+            busrt.client.Frame(pack({'status': status}),
+                               tp=busrt.client.OP_PUBLISH,
                                qos=0))
 
     def register_signals(self):
@@ -480,7 +482,7 @@ class Service:
 
 
 def no_rpc_method():
-    raise elbus.rpc.RpcException('no such method', ERR_CODE_METHOD_NOT_FOUND)
+    raise busrt.rpc.RpcException('no such method', ERR_CODE_METHOD_NOT_FOUND)
 
 
 def log_traceback():
